@@ -1,3 +1,17 @@
+# Copyright (c) 2012-2013 Trevor L Davis <trevor.l.davis@stanford.edu>
+#  
+#  This file is free software: you may copy, redistribute and/or modify it  
+#  under the terms of the GNU General Public License as published by the  
+#  Free Software Foundation, either version 2 of the License, or (at your  
+#  option) any later version.  
+#  
+#  This file is distributed in the hope that it will be useful, but  
+#  WITHOUT ANY WARRANTY; without even the implied warranty of  
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  
+#  General Public License for more details.  
+#  
+#  You should have received a copy of the GNU General Public License  
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.  
 context("Unit tests")
 
 options(python_cmd = find_python_cmd())
@@ -45,6 +59,15 @@ test_that("add_argument works as expected", {
     expect_equal(arguments$integers, c(1,2))
     expect_equal(f(arguments$integers), 3)
     expect_error(parser$add_argument("--foo", type="boolean"))
+
+    # Bug found by Martin Diehl
+    parser$add_argument('--label',type='character',nargs=2,
+        dest='label',action='store',default=c("a","b"),help='label for X and Y axis')
+    parser$add_argument('--bool',type='logical',nargs=2,
+        dest='bool',action='store',default=c(FALSE, TRUE))
+    arguments <- parser$parse_args(c("--sum", "1", "2"))
+    expect_equal(arguments$label, c("a", "b"))
+    expect_equal(arguments$bool, c(FALSE, TRUE))
 })
 
 context("ArgumentParser")
